<?php
/**
 * Explorer configuration script
 *
 * Configuration of standard photo album resource
 * this script is included by /res/administration/std/resourceConfig.php
 * this script should never be directly called.
 *
 * resourceConfig.php sets 2 variables :
 * $resourceData (array) which contains resource parameters
 * $_ENV['configurationEnvironment'] which indicates if resourceConfig.php has been called from browser ('browser')
 * or from application's embeded browser ('application')
 *
 * PHP version 5
 *
 * LICENSE: This source file is subject to version 3.0 of the PHP license
 * that is available through the world-wide-web at the following URI:
 * http://www.php.net/license/3_0.txt.  If you did not receive a copy of
 * the PHP License and are unable to obtain it through the web, please
 * send a note to license@php.net so we can mail you a copy immediately.
 *
 * @category   NA
 * @package    NA
 * @author     Nicolas Bruley / Peer 2 World <contact@weezo.net>
 * @copyright  2005-2009 Nicolas Bruley / Peer 2 World
 * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
 * @version    CVS: $Id:$
 * @link       http://www.weezo.net
 * @since      File available since Release 1.0.0
 */


/*
 ***************************************************************************************************************************
 * Verify access rights
 ***************************************************************************************************************************
 */
require_once(INCLUDE_DIR.'resourceConfigFunctions.php');
rcConfigRights(false);

//#############################################################################################################
// Display configuration form
//#############################################################################################################

// Insert Javascript function needed for save button activation, and <form> with hidden fields.
rcInsertScriptAndForm();

/*
 * Common explorers parameters
 */

// Resource icon & name
rcInsertIconName($resourceData,true,array('rcSharedFilesBox'=>array(false,WEnv::host()->specialFolderDocuments())));

// Shared folder or items
//rcSharedFilesBox(false,WEnv::host()->specialFolderDocuments());


/**
 * Access rights
 */
if(cfSimpleMode()) {
	rcAdvancedConfigStart();
	echo '<br><br>';
}

echo '<div class="frame2">';
echo '<div class="frame2Header">'.cfCaption('configAccessRights').'</div>';

rcProcessData('downloadAllowed',dataUserRights,'all',false,cfCaption('explorerCfgDownload'),false); // Allow/Forbid read access to files and folders

$resourceData['userRights_downloadShortcut']=$resourceData['userRights_downloadAllowed']; // if download allowed, display shortcut
$resourceData['userRights_fileViewAllowed']=$resourceData['userRights_downloadAllowed'];// If download allowed, allow direct file view

// Multiple download
rcProcessData('multipleDownloadAllowed',dataUserRights,'all',false,cfCaption('configAllowMultipleDownload').'&nbsp;&nbsp;&nbsp;'.outHelpButton('helpMD'),false);

rcProcessData('mDownloadPrecomputeSize',dataBoolean,true,false,false/*do not display control*/); // Compute total multiple download file nb and size


rcProcessData('writeAllowed',dataUserRights,'admin',false,cfCaption('explorerCfgWrite'),false,true); // Allow/Forbidwrite access to files and folders
rcProcessData('modifyAllowed',dataUserRights,'none',false,cfCaption('explorerCfgModify'),false,true); // Allow/Forbid modifcation access to files and folders (need writeAllowed to true)
rcProcessData('editionAllowed',dataUserRights,'none',false,cfCaption('explorerCfgEdition'),false,true); // Allow/Forbid remote text files edition (need writeAllowed to true)
rcProcessData('createFolderAllowed',dataUserRights,'none',false,cfCaption('explorerCfgCreateFolder'),false); // Allow/Forbid execute access to files
rcProcessData('executeAllowed',dataUserRights,'none',false,cfCaption('explorerCfgExecute'),false,true); // Allow/Forbid execute access to files
rcProcessData('uploadAllowed',dataUserRights,'admin',false,cfCaption('explorerCfgUpload').'&nbsp;&nbsp;&nbsp;'.outHelpButton('helpCfgUpload'),false,true); // Allow/Forbid file upload

rcProcessData('remoteDownloadAllowed',dataUserRights,'admin',false,cfCaption('explorerCfgRemoteDownload').'&nbsp;&nbsp;&nbsp;'.outHelpButton('helpDDL'),false,true); // Allow/Forbid remote download of files

rcProcessData('shareAllowed',dataUserRights,'none',false,cfCaption('shareAllowed').'&nbsp;&nbsp;&nbsp;'.outHelpButton('shareHelp','doShare'),false,false); // Allow/Forbid remote creation of direct link

rcProcessData('mailoutAllowed',dataUserRights,'admin',false,cfCaption('sendByMail').'&nbsp;&nbsp;&nbsp;'.rcMailoutConfigButton(),false,false,array('faded'=>!Mailout::isMainConfigurationSet())); // Allow/Forbid emailing files

if(cfGGetVar('ratingAllowed')) rcProcessData('ratingAllowed',dataUserRights,'none',false,cfCaption('ratingAllowed'),false,false); // Allow/Forbid file rating

//rcProcessData('sendAllowed',dataBoolean,false,false,cfCaption('explorerCfgTransfer')); // Allow/Forbid send files

// Defines write rights from other options
//if($resourceData['modifyAllowed'] || $resourceData['createFolderAllowed'] || $resourceData['uploadAllowed'])  $resourceData['writeAllowed']=true;

rcProcessData('destroyDeletedFiles',dataBoolean,false,false,false/*do not display control*/); // Set to true to destroy deleted files instead of sending them to recycle bin)
rcProcessData('userTempDirAccessAllowed',dataBoolean,false,false,false/*do not display control*/); // Allow/Forbid access to user temp directory (data/sessiondata/(session_id)/)
rcProcessData('resourceDataDirAccessAllowed',dataBoolean,false,false,false/*do not display control*/); // Allow/Forbid access to resource directory (data/res/(res type)/(res subType)/(res file name)/)
rcProcessData('searchFiles',dataBoolean,true,false,false/*do not display control*/); 					// Allow/Forbid search)
rcProcessData('searchFilesContentAllowed',dataBoolean,true,false,false/*do not display control*/); 	// Allow content search)
rcProcessData('searchFilesContentDefault',dataBoolean,false,false,false/*do not display control*/); 	// Disable content search by default)

rcProcessData('displayExtraData',dataBoolean,false,false,false/*do not display control*/); // Display files extra data in explorer (slower)

echo '</div>';

// Max number of drag items (defined at general level, if set at resource level will override general value
// rcProcessData('maxDragItems',dataNumeric,100,false,false,false/*do not display control*/);

/*
 * Image gallery specific parameters
 */

// Indicate that thumbnails must be generated
rcProcessData('photoThumbnailsNeeded',dataBoolean,false,false,false/*do not display control*/); // Generate images thumbnails when browsing a dir
rcProcessData('showExifData',dataBoolean,true,false,false,false/*do not display control*/); // Display exif data in preview mode


/**
 * Video specific parameters
 */
rcProcessData('reencodedVideo',dataBoolean,true,false,false/*do not display control*/); // Allow flash real-time reencoding
rcProcessData('flashStream',dataBoolean,true,false,false/*do not display control*/); // Force real-time reencoding (no cache file)
rcProcessData('flashOutputQuality',dataText,'original',false,false/*do not display control*/); // Default & max quality
rcProcessData('flashOutputSize',dataText,'original',false,false/*do not display control*/); // Default & max dimensions
rcProcessData('flashOutputSizeMax',dataText,'original',false,false/*do not display control*/); // Default & max dimensions
rcProcessData('flashOutputQualityMax',dataText,'original',false,false/*do not display control*/); // Default & max dimensions
rcProcessData('flvAllowed',dataBoolean,true,false,false);				// Flash (flv & f4v if GPL ffmpeg & flash player>10) video
rcProcessData('f4vForbidden',dataBoolean,false,false,false);			// Do not forbid F4V / h264 encoding
rcProcessData('webmAllowed',dataBoolean,true,false,false);				// WebM video through HTML5 video player
rcProcessData('ogvAllowed',dataBoolean,true,false,false);				// Ogg Theora video through HTML5 video player
rcProcessData('allowOriginalVideo',dataBoolean,true,false,false);		// Allow non-reencoded video

// End of advanced config
if(cfSimpleMode()) rcAdvancedConfigEnd();

echo outConfigSeparator();

// Layout type
if(!cfSimpleMode()){
	rcProcessData('layout',dataList,'2',array('0','1','2','3'),array(
	array('<b>'.cfCaption('genDisplay').'</b>','0',array(rcResourceImage('configFramesTopLeft.gif'),'&nbsp;')),
	array(false,'1',array(rcResourceImage('configFrameTop.gif'),'&nbsp;')),
	array(false,'2',array(rcResourceImage('configFrameLeft.gif'),'&nbsp;')),
	array(false,'3',array(rcResourceImage('configNoFrames.gif'),''))));
}
else rcProcessData('layout',dataList,0,array('0','1','2','3'),false/*do not display control*/); // Allow flash real-time reencoding


// Layout
rcProcessData('filesLayout',dataText,'list',false,false/*do not display control*/); // Default files layout: FilesList list */
rcProcessData('filesLayoutLocked',dataBoolean,false,false,false/*do not display control*/); // Do not lock files layout (allow user to change) */
echo '<br>';


// Comments panel
echo rcCommentsPanelControl();

// Resource theme
echo '<div style="padding-bottom:0;vertical-align:middle">'.rcThemeSelectionControl().'</div>';

// Save / cancel buttons
echo rcButtonSaveCancel();

// If resource need access to resource data dir, create it
rcCreateResourceDataDir();

// Indicate that resource has been initialized
rcProcessData('resourceConfigured',dataBoolean,true,false,false/*do not display control*/);

// Save parameters
rcWriteResourceFile($resourceData, $fileName);
/*

SAMPLE DATA

// Sample boolean data, default value=true, no constraint, checkbox with icon and 'blabla' caption
rcProcessData('testData',dataBoolean,true,false,array(array(outIcon('suppr'),'blabla')));

// Sample boolean data, default value=true, no constraint, radio buttons with icons and captions
rcProcessData('testData2',dataBoolean,true,false,array(array(outIcon('ok'),'item is true'),array(outIcon('false'),'item is false')));

// Sample text data
rcProcessData('testData3',dataText,'default value 1',array(3,10),array(10,array(outIcon('ok'),'right caption and ok button')));
rcProcessData('testData4',dataText,'default value 2',array(3,10),array('left caption',3));
rcProcessData('testData5',dataText,'default value 3',array(3,10),array(array(outIcon('ok'),'Left caption and OK button'),1,'right caption'));

// Sample numeric data, default value=5, min = 1 & max = 10
rcProcessData('testData6',dataNumeric,5,array(1,10),array(1,'right caption'));



// Values list
rcProcessData('testData8',dataList,'v1',array('v1','v2','v3'),array(array('Value 1','v1','<br>'),array('Value 2','v2','<br>'),array(false,'v3', 'Value 3')));

*/
?>
<script language="javascript" type="text/javascript">
function dataChanged(dataName,dataValue){
	if(dataName=="writeAllowed"){
		if(!dataValue){
			dgn("modifyAllowed").disabled=true;
			dgn("modifyAllowed").checked=false;

			dgn("editionAllowed").disabled=true;
			dgn("editionAllowed").checked=false;

			dgn("createFolderAllowed").disabled=true;
			dgn("createFolderAllowed").checked=false;

			dgn("uploadAllowed").disabled=true;
			dgn("uploadAllowed").checked=false;

			dgn("remoteDownloadAllowed").disabled=true;
			dgn("remoteDownloadAllowed").checked=false;
		}
		else{
			dgn("modifyAllowed").disabled=false;
			dgn("createFolderAllowed").disabled=false;
			dgn("uploadAllowed").disabled=false;
			dgn("remoteDownloadAllowed").disabled=false;
			if(dgn("modifyAllowed").checked)
				dgn("editionAllowed").disabled=false;
			else
				dgn("editionAllowed").disabled=true;
		}
	}
	if(dataName=="modifyAllowed"){
		if(!dataValue){
			dgn("editionAllowed").disabled=true;
			dgn("editionAllowed").checked=false;
		}
		else{
			dgn("editionAllowed").disabled=false;
		}
	}
	if(dataName=="downloadAllowed"){
		if(!dataValue){
			dgn("multipleDownloadAllowed").disabled=true;
			dgn("multipleDownloadAllowed").checked=false;
		}
		else{
			dgn("multipleDownloadAllowed").disabled=false;
		}
	}
}

function dataInitForm(){
	dataChangedNV("writeAllowed");
	dataChangedNV("modifyAllowed");
	dataChangedNV("downloadAllowed");
}
rcUserRightsLink('writeAllowed','uploadAllowed');
rcUserRightsLink('writeAllowed','modifyAllowed');
rcUserRightsLink('writeAllowed','remoteDownloadAllowed');
rcUserRightsLink('writeAllowed','editionAllowed');
rcUserRightsLink('modifyAllowed','editionAllowed');
dataInitForm();
</script>